@@ -86,7 +86,10 @@ def build(input_graph_string):
         node.use_ipv4 = allocate_ipv4_infrastructure
         node.use_ipv6 = allocate_ipv6
 
-    igp = g_in.data.igp or "ospf" 
+    default_igp = g_in.data.igp or "ospf" 
+    non_igp_nodes = [n for n in g_in if not node.igp]
+    g_in.update(non_igp_nodes, igp=default_igp)
+
     anm.add_overlay("ospf")
     anm.add_overlay("isis")
 
@@ -95,6 +98,8 @@ def build(input_graph_string):
     build_ospf(anm)
     build_isis(anm)
     build_bgp(anm)
+    autonetkit.update_http(anm)
+    autonetkit.update_http(anm)
 
     return anm
 
@@ -419,9 +424,9 @@ def build_ipv4(anm, infrastructure=True):
         ank_utils.split(g_ipv4, edges_to_split, retain='edge_id'))
     for node in split_created_nodes:
         node['graphics'].x = ank_utils.neigh_average(g_ipv4, node, "x",
-                                                     g_graphics)
+                                                     g_graphics) + 0.1 # temporary fix for gh-90
         node['graphics'].y = ank_utils.neigh_average(g_ipv4, node, "y",
-                                                     g_graphics)
+                                                     g_graphics) + 0.1 # temporary fix for gh-90
         asn = ank_utils.neigh_most_frequent(
             g_ipv4, node, "asn", g_phy)  # arbitrary choice
         node['graphics'].asn = asn
